@@ -11,21 +11,35 @@ class ModelCoreTest(unittest.TestCase):
         N = 0
 
         class Model(elegy.model.model_core.ModelCore):
-            def pred_step(self):
+            def states_step(self):
+                return elegy.States(
+                    net_params=None,
+                    net_states=None,
+                    metrics_states=None,
+                    optimizer_states=None,
+                )
+
+            def init_step(self, states):
+                states = states.maybe_update(**self.states_step())
+                _, states = self.train_step(states)
+
+                return states
+
+            def pred_step(self, states):
                 nonlocal N
                 N = N + 1
 
                 return elegy.PredStep(
                     y_pred=None,
-                    states=elegy.States(net_params=1, net_states=2),
+                    states=states.update(net_params=1, net_states=2),
                 )
 
-            def test_step(self):
-                _, states = self.pred_step()
+            def test_step(self, states):
+                _, states = self.pred_step(states)
                 return elegy.TestStep(0, {}, states.update(metrics_states=3))
 
-            def train_step(self):
-                _, logs, states = self.test_step()
+            def train_step(self, states):
+                _, logs, states = self.test_step(states)
                 return elegy.TrainStep(logs, states.update(optimizer_states=4))
 
         model = Model()
@@ -36,36 +50,23 @@ class ModelCoreTest(unittest.TestCase):
         assert not hasattr(model.states, "metrics_states")
         assert not hasattr(model.states, "optimizer_states")
 
-        model.maybe_initialize(elegy.types.Mode.pred)
+        model.init_on_batch()
 
         assert N == 1
         assert model.states.net_params == 1
         assert model.states.net_states == 2
-
-        model.maybe_initialize(elegy.types.Mode.pred)
-
-        assert N == 1
-
-        model.maybe_initialize(elegy.types.Mode.test)
-
-        assert N == 2
         assert model.states.metrics_states == 3
-
-        model.maybe_initialize(elegy.types.Mode.test)
-
-        assert N == 2
-
-        model.maybe_initialize(elegy.types.Mode.train)
-
-        assert N == 3
         assert model.states.optimizer_states == 4
 
-        model.maybe_initialize(elegy.types.Mode.train)
-
-        assert N == 3
+        model.init_on_batch()
+        assert N == 1
 
     def test_pred_step(self):
         class Model(elegy.model.model_core.ModelCore):
+            def init_step(self, x, states):
+                _, states = self.pred_step(x, states, True)
+                return states
+
             def pred_step(self, x, states, initializing):
                 if initializing:
                     states = elegy.States(net_states=0)
@@ -77,15 +78,10 @@ class ModelCoreTest(unittest.TestCase):
                     states=states,
                 )
 
-            def test_step(self):
-                ...
-
-            def train_step(self):
-                ...
-
         model = Model()
         assert not hasattr(model.states, "net_states")
 
+        model.init_on_batch(x=(np.array(1.0)))
         preds = model.predict_on_batch(x=(np.array(1.0)))
         assert preds == 1
         assert model.states.net_states == 1
@@ -99,6 +95,10 @@ class ModelCoreTest(unittest.TestCase):
 
     def test_test_step(self):
         class Model(elegy.model.model_core.ModelCore):
+            def init_step(self, states):
+                _, _, states = self.test_step(states, True)
+                return states
+
             def test_step(self, states, initializing):
                 return elegy.TestStep(
                     loss=0.1,
@@ -127,6 +127,10 @@ class ModelCoreTest(unittest.TestCase):
 
     def test_train_step(self):
         class Model(elegy.model.model_core.ModelCore):
+            def init_step(self, states):
+                _, states = self.train_step(states, True)
+                return states
+
             def train_step(self, states, initializing):
                 return elegy.TrainStep(
                     logs=dict(loss=2.0),
